# Manual

Automatic controller documentation using rspec
- No specific DSL
- No bloated controllers
- Always in sync with the tests
- Generates documentation in JSON and HTML for distribution

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'manual'
```

And then execute:

    $ bundle install

Or install it yourself as:

    $ gem install manual

## Usage

```ruby
RSpec.configure do |config|
  Manual::Generator.setup(config)
end

# use `manual: :record` to add the example to the generated manual
RSpec.describe Api::V1::SessionsController, type: :controller do
  describe "#create" do
    it "responds with a 200 OK", manual: :record do
      user = FactoryBot.create(:user)

      post :create, params: { email: user.email, password: user.password }

      expect(response.status).to eq(200)
    end
  end
end
```

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/prrrnd/manual.


## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
